#!/usr/bin/env python

"""
An emulator back-end for the protocol. Starts a sub-process and connects the
standard input and output pipes to the read/write interface.
"""

from ctypes import *

from back_end.base import BackEnd

class DEPPBackEnd(BackEnd):

    def __init__(self):
        """
        Starts the emulator specified in args as a sub-process. Args should be a
        valid shell command string.
        """
        BackEnd.__init__(self)

        self.name = "DEPP"
        self.depp = ''

        #
        self.libdepp = CDLL("libdepp.so")
        self.libdmgr = CDLL("libdmgr.so")
        self.hackie_uart_handle = c_int()
        self.libdmgr.DmgrOpen(byref(self.hackie_uart_handle), b"CmodS6")
        self.libdepp.DeppEnable(self.hackie_uart_handle)
        self.byte_in = c_char()



    def read(self, length):
        bytes_out = b""
        i = 1
        while i <= length:
                # Flow control is currently turned off - uncomment in read and write
                # function to turn on

                #self.libdepp.DeppGetReg(self.hackie_uart_handle, 2, byref(self.byte_in), 0)
                ##print(ord(byte_in.value))
                #if(ord(self.byte_in.value) == 1):
                self.libdepp.DeppGetReg(self.hackie_uart_handle, 3, byref(self.byte_in), 0)
                bytes_out = bytes_out + self.byte_in.value
                i = i + 1
        return(bytes_out)


    def write(self, data):
        for n in data :
            ##print(" ",n)
            #self.byte_in = c_char(chr(0))
            #while(ord(self.byte_in.value) == 0):
                            #self.libdepp.DeppGetReg(self.hackie_uart_handle, 0, byref(self.byte_in), 0)
            self.libdepp.DeppPutReg(self.hackie_uart_handle, 1, c_byte(ord(n)), 0)
            #self.libdepp.DeppPutReg(self.hackie_uart_handle, 1, c_char(n.encode()), 0)
        return


    def flush(self):
        return


    def close(self):
        return
