#!/usr/bin/env python

"""
An emulator back-end for the protocol. Starts a sub-process and connects the
standard input and output pipes to the read/write interface.
"""

from ctypes import *

from subprocess import Popen, PIPE

from back_end.base import BackEnd

from ctypes import cdll
import traceback
import binascii
import psutil

class EmulatorBackEnd(BackEnd):

	def __init__(self, args):
		"""
		Starts the emulator specified in args as a sub-process. Args should be a
		valid shell command string.
		"""
		BackEnd.__init__(self)

		self.name = "Emulator"

		# Start the emulator as a child-process
		self.emulator = Popen(args,
		                      bufsize = -1,   # Produce a fully-buffered set of pipes
		                      stdin   = PIPE, # Source stdin from the protocol
		                      stdout  = PIPE, # Supply stdout to the protocol
		                      stderr  = None, # Stderr should not be redirected
		                      shell   = True) # Execute in a shell
				    

	def read(self, length):
		data = self.emulator.stdout.read(length)
		#print("Read "+str(binascii.hexlify(data)))
		return data


	def write(self, data):
		bytedata = bytearray() # Line added by JSP 19-8-2020 create byte arrary
		bytedata.extend(map(ord, data)) # Line added by JSP 19-8-2020 convert string to byte array
		#bytedata = bytes(data, 'ascii') # Line removed by JSP 19-8-2020 
		#print("Writing '"+str(binascii.hexlify(bytedata))+"'")
		self.emulator.stdin.write(bytedata)


	def flush(self):
		self.emulator.stdin.flush()


	def close(self):
		print("Kill called")
		self.emulator.stdin.close()
		self.emulator.stdout.close()
		#self.emulator.kill()
		process = psutil.Process(self.emulator.pid)
		for proc in process.children(recursive=True) :
			print(proc)
			proc.kill()
		process.kill()
