#!/usr/bin/env python

"""
A GTK+ widget which can be used to fill space where a widget is unavailable, for
example if a system doesn't have a memory, this can be shown in its place in a
memory window.
"""


from gi.repository import Gtk as gtk

class Placeholder(gtk.Box):

	def __init__(self, title, body = None, stock_icon_id = gtk.STOCK_DIALOG_INFO):
		"""
		Draws an icon, large title and some body text centered in the widget.
		"""
		gtk.Box.__init__(self)

		self.title         = title
		self.body          = body or ""
		self.stock_icon_id = stock_icon_id

		self.vbox = gtk.VBox(spacing = 15)
		self.vbox.set_border_width(15)
		self.add(self.vbox)

		self.icon = gtk.Image()
		self.icon.set_from_stock(self.stock_icon_id, gtk.IconSize.DIALOG)
		self.vbox.pack_start(self.icon, True, False, 1)

		self.title_label = gtk.Label()
		self.title_label.set_markup("<span weight = 'bold' size='x-large'>%s</span>"%self.title)
		self.vbox.pack_start(self.title_label, True, False, 1)

		self.body_label = gtk.Label()
		self.body_label.set_markup(self.body)
		self.body_label.set_line_wrap(True)
		self.vbox.pack_start(self.body_label, True, False, 1)

		self.vbox.show_all()
